@@ -8,16 +8,7 @@ has usage       => "usage: $0 psgi\n";
 
 # "In the end it was not guns or bombs that defeated the aliens,
 #  but that humblest of all God's creatures... the Tyrannosaurus Rex."
-sub run {
-  my $self = shift;
-
-  # Preload
-  my $psgi = Mojo::Server::PSGI->new;
-  $psgi->app;
-
-  # Return app callback
-  return sub { $psgi->run(@_) };
-}
+sub run { Mojo::Server::PSGI->new->to_psgi }
 
 1;
 __END__
